@@ -13,6 +13,7 @@ myEstPaucT <- function(x, y, partial, eps=0.05, epsT=(length(x))^(-0.75)){
   H12 <- as.matrix(1-smooth3(x=x, y=rep(tauEst, ny), eps=epsT))
     ####  in the future, change smooth3 to smooth3vec. No need to rep(tauEst,.)###
   H1 <- H11*H12
-  PaucEst <- as.numeric(rep(1/nx, nx)%*% H1 %*%rep(1/ny, ny))
+  ####  PaucEst <- as.numeric(rep(1/nx, nx)%*% H1 %*%rep(1/ny, ny))
+  PaucEst <- sum(H1)/(nx*ny)    ### changed 1/13/2023 by M.Zhou
 list("tau(1-partial)"=tauEst, "Pauc(0,partial)"=PaucEst)
 }
